==> gwyddion_2.26.orig.tar.xz: gwyddion-2.26/app/gwyapptypes.c <==
/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#include "gwyapptypes.h"

#include "./data-browser.h"

GType
gwy_app_what_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_APP_CONTAINER, "GWY_APP_CONTAINER", "container" },
            { GWY_APP_DATA_VIEW, "GWY_APP_DATA_VIEW", "data-view" },
            { GWY_APP_GRAPH, "GWY_APP_GRAPH", "graph" },
            { GWY_APP_DATA_FIELD, "GWY_APP_DATA_FIELD", "data-field" },
            { GWY_APP_DATA_FIELD_KEY, "GWY_APP_DATA_FIELD_KEY", "data-field-key" },
            { GWY_APP_DATA_FIELD_ID, "GWY_APP_DATA_FIELD_ID", "data-field-id" },
            { GWY_APP_MASK_FIELD, "GWY_APP_MASK_FIELD", "mask-field" },
            { GWY_APP_MASK_FIELD_KEY, "GWY_APP_MASK_FIELD_KEY", "mask-field-key" },
            { GWY_APP_SHOW_FIELD, "GWY_APP_SHOW_FIELD", "show-field" },
            { GWY_APP_SHOW_FIELD_KEY, "GWY_APP_SHOW_FIELD_KEY", "show-field-key" },
            { GWY_APP_GRAPH_MODEL, "GWY_APP_GRAPH_MODEL", "graph-model" },
            { GWY_APP_GRAPH_MODEL_KEY, "GWY_APP_GRAPH_MODEL_KEY", "graph-model-key" },
            { GWY_APP_GRAPH_MODEL_ID, "GWY_APP_GRAPH_MODEL_ID", "graph-model-id" },
            { GWY_APP_SPECTRA, "GWY_APP_SPECTRA", "spectra" },
            { GWY_APP_SPECTRA_KEY, "GWY_APP_SPECTRA_KEY", "spectra-key" },
            { GWY_APP_SPECTRA_ID, "GWY_APP_SPECTRA_ID", "spectra-id" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyAppWhat", values);
    }
    return etype;
}

GType
gwy_data_item_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DATA_ITEM_GRADIENT, "GWY_DATA_ITEM_GRADIENT", "gradient" },
            { GWY_DATA_ITEM_PALETTE, "GWY_DATA_ITEM_PALETTE", "palette" },
            { GWY_DATA_ITEM_MASK_COLOR, "GWY_DATA_ITEM_MASK_COLOR", "mask-color" },
            { GWY_DATA_ITEM_TITLE, "GWY_DATA_ITEM_TITLE", "title" },
            { GWY_DATA_ITEM_RANGE, "GWY_DATA_ITEM_RANGE", "range" },
            { GWY_DATA_ITEM_RANGE_TYPE, "GWY_DATA_ITEM_RANGE_TYPE", "range-type" },
            { GWY_DATA_ITEM_REAL_SQUARE, "GWY_DATA_ITEM_REAL_SQUARE", "real-square" },
            { GWY_DATA_ITEM_SELECTIONS, "GWY_DATA_ITEM_SELECTIONS", "selections" },
            { GWY_DATA_ITEM_META, "GWY_DATA_ITEM_META", "meta" },
            { GWY_DATA_ITEM_CALDATA, "GWY_DATA_ITEM_CALDATA", "caldata" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDataItem", values);
    }
    return etype;
}

GType
gwy_visibility_reset_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_VISIBILITY_RESET_DEFAULT, "GWY_VISIBILITY_RESET_DEFAULT", "default" },
            { GWY_VISIBILITY_RESET_RESTORE, "GWY_VISIBILITY_RESET_RESTORE", "restore" },
            { GWY_VISIBILITY_RESET_SHOW_ALL, "GWY_VISIBILITY_RESET_SHOW_ALL", "show-all" },
            { GWY_VISIBILITY_RESET_HIDE_ALL, "GWY_VISIBILITY_RESET_HIDE_ALL", "hide-all" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyVisibilityResetType", values);
    }
    return etype;
}

GType
gwy_data_watch_event_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DATA_WATCH_EVENT_ADDED, "GWY_DATA_WATCH_EVENT_ADDED", "added" },
            { GWY_DATA_WATCH_EVENT_CHANGED, "GWY_DATA_WATCH_EVENT_CHANGED", "changed" },
            { GWY_DATA_WATCH_EVENT_REMOVED, "GWY_DATA_WATCH_EVENT_REMOVED", "removed" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDataWatchEventType", values);
    }
    return etype;
}

#include "./menu.h"

GType
gwy_menu_sens_flags_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GFlagsValue values[] = {
            { GWY_MENU_FLAG_DATA, "GWY_MENU_FLAG_DATA", "data" },
            { GWY_MENU_FLAG_UNDO, "GWY_MENU_FLAG_UNDO", "undo" },
            { GWY_MENU_FLAG_REDO, "GWY_MENU_FLAG_REDO", "redo" },
            { GWY_MENU_FLAG_GRAPH, "GWY_MENU_FLAG_GRAPH", "graph" },
            { GWY_MENU_FLAG_LAST_PROC, "GWY_MENU_FLAG_LAST_PROC", "last-proc" },
            { GWY_MENU_FLAG_LAST_GRAPH, "GWY_MENU_FLAG_LAST_GRAPH", "last-graph" },
            { GWY_MENU_FLAG_DATA_MASK, "GWY_MENU_FLAG_DATA_MASK", "data-mask" },
            { GWY_MENU_FLAG_DATA_SHOW, "GWY_MENU_FLAG_DATA_SHOW", "data-show" },
            { GWY_MENU_FLAG_3D, "GWY_MENU_FLAG_3D", "3d" },
            { GWY_MENU_FLAG_FILE, "GWY_MENU_FLAG_FILE", "file" },
            { GWY_MENU_FLAG_MASK, "GWY_MENU_FLAG_MASK", "mask" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static("GwyMenuSensFlags", values);
    }
    return etype;
}

#include "./gwymoduleutils-file.h"

GType
gwy_text_header_error_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_TEXT_HEADER_ERROR_SECTION_NAME, "GWY_TEXT_HEADER_ERROR_SECTION_NAME", "section-name" },
            { GWY_TEXT_HEADER_ERROR_SECTION_END, "GWY_TEXT_HEADER_ERROR_SECTION_END", "section-end" },
            { GWY_TEXT_HEADER_ERROR_SECTION_START, "GWY_TEXT_HEADER_ERROR_SECTION_START", "section-start" },
            { GWY_TEXT_HEADER_ERROR_PREFIX, "GWY_TEXT_HEADER_ERROR_PREFIX", "prefix" },
            { GWY_TEXT_HEADER_ERROR_GARBAGE, "GWY_TEXT_HEADER_ERROR_GARBAGE", "garbage" },
            { GWY_TEXT_HEADER_ERROR_KEY, "GWY_TEXT_HEADER_ERROR_KEY", "key" },
            { GWY_TEXT_HEADER_ERROR_VALUE, "GWY_TEXT_HEADER_ERROR_VALUE", "value" },
            { GWY_TEXT_HEADER_ERROR_TERMINATOR, "GWY_TEXT_HEADER_ERROR_TERMINATOR", "terminator" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyTextHeaderError", values);
    }
    return etype;
}

#include "./gwyplaintool.h"

GType
gwy_plain_tool_changed_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GFlagsValue values[] = {
            { GWY_PLAIN_TOOL_CHANGED_DATA, "GWY_PLAIN_TOOL_CHANGED_DATA", "changed-data" },
            { GWY_PLAIN_TOOL_CHANGED_MASK, "GWY_PLAIN_TOOL_CHANGED_MASK", "changed-mask" },
            { GWY_PLAIN_TOOL_CHANGED_SHOW, "GWY_PLAIN_TOOL_CHANGED_SHOW", "changed-show" },
            { GWY_PLAIN_TOOL_CHANGED_SELECTION, "GWY_PLAIN_TOOL_CHANGED_SELECTION", "changed-selection" },
            { GWY_PLAIN_TOOL_FINISHED_SELECTION, "GWY_PLAIN_TOOL_FINISHED_SELECTION", "finished-selection" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static("GwyPlainToolChanged", values);
    }
    return etype;
}

#include "./settings.h"

GType
gwy_app_settings_error_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_APP_SETTINGS_ERROR_FILE, "GWY_APP_SETTINGS_ERROR_FILE", "file" },
            { GWY_APP_SETTINGS_ERROR_CORRUPT, "GWY_APP_SETTINGS_ERROR_CORRUPT", "corrupt" },
            { GWY_APP_SETTINGS_ERROR_CFGDIR, "GWY_APP_SETTINGS_ERROR_CFGDIR", "cfgdir" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyAppSettingsError", values);
    }
    return etype;
}


/* Generated data ends here */

==> gwyddion_2.34.orig.tar.xz: gwyddion-2.34/app/gwyapptypes.c <==
/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#include "gwyapptypes.h"

#include "./data-browser.h"

GType
gwy_app_what_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_APP_CONTAINER, "GWY_APP_CONTAINER", "container" },
            { GWY_APP_DATA_VIEW, "GWY_APP_DATA_VIEW", "data-view" },
            { GWY_APP_GRAPH, "GWY_APP_GRAPH", "graph" },
            { GWY_APP_DATA_FIELD, "GWY_APP_DATA_FIELD", "data-field" },
            { GWY_APP_DATA_FIELD_KEY, "GWY_APP_DATA_FIELD_KEY", "data-field-key" },
            { GWY_APP_DATA_FIELD_ID, "GWY_APP_DATA_FIELD_ID", "data-field-id" },
            { GWY_APP_MASK_FIELD, "GWY_APP_MASK_FIELD", "mask-field" },
            { GWY_APP_MASK_FIELD_KEY, "GWY_APP_MASK_FIELD_KEY", "mask-field-key" },
            { GWY_APP_SHOW_FIELD, "GWY_APP_SHOW_FIELD", "show-field" },
            { GWY_APP_SHOW_FIELD_KEY, "GWY_APP_SHOW_FIELD_KEY", "show-field-key" },
            { GWY_APP_GRAPH_MODEL, "GWY_APP_GRAPH_MODEL", "graph-model" },
            { GWY_APP_GRAPH_MODEL_KEY, "GWY_APP_GRAPH_MODEL_KEY", "graph-model-key" },
            { GWY_APP_GRAPH_MODEL_ID, "GWY_APP_GRAPH_MODEL_ID", "graph-model-id" },
            { GWY_APP_SPECTRA, "GWY_APP_SPECTRA", "spectra" },
            { GWY_APP_SPECTRA_KEY, "GWY_APP_SPECTRA_KEY", "spectra-key" },
            { GWY_APP_SPECTRA_ID, "GWY_APP_SPECTRA_ID", "spectra-id" },
            { GWY_APP_VOLUME_VIEW, "GWY_APP_VOLUME_VIEW", "volume-view" },
            { GWY_APP_BRICK, "GWY_APP_BRICK", "brick" },
            { GWY_APP_BRICK_KEY, "GWY_APP_BRICK_KEY", "brick-key" },
            { GWY_APP_BRICK_ID, "GWY_APP_BRICK_ID", "brick-id" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyAppWhat", values);
    }
    return etype;
}

GType
gwy_data_item_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DATA_ITEM_GRADIENT, "GWY_DATA_ITEM_GRADIENT", "gradient" },
            { GWY_DATA_ITEM_PALETTE, "GWY_DATA_ITEM_PALETTE", "palette" },
            { GWY_DATA_ITEM_MASK_COLOR, "GWY_DATA_ITEM_MASK_COLOR", "mask-color" },
            { GWY_DATA_ITEM_TITLE, "GWY_DATA_ITEM_TITLE", "title" },
            { GWY_DATA_ITEM_RANGE, "GWY_DATA_ITEM_RANGE", "range" },
            { GWY_DATA_ITEM_RANGE_TYPE, "GWY_DATA_ITEM_RANGE_TYPE", "range-type" },
            { GWY_DATA_ITEM_REAL_SQUARE, "GWY_DATA_ITEM_REAL_SQUARE", "real-square" },
            { GWY_DATA_ITEM_SELECTIONS, "GWY_DATA_ITEM_SELECTIONS", "selections" },
            { GWY_DATA_ITEM_META, "GWY_DATA_ITEM_META", "meta" },
            { GWY_DATA_ITEM_CALDATA, "GWY_DATA_ITEM_CALDATA", "caldata" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDataItem", values);
    }
    return etype;
}

GType
gwy_visibility_reset_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_VISIBILITY_RESET_DEFAULT, "GWY_VISIBILITY_RESET_DEFAULT", "default" },
            { GWY_VISIBILITY_RESET_RESTORE, "GWY_VISIBILITY_RESET_RESTORE", "restore" },
            { GWY_VISIBILITY_RESET_SHOW_ALL, "GWY_VISIBILITY_RESET_SHOW_ALL", "show-all" },
            { GWY_VISIBILITY_RESET_HIDE_ALL, "GWY_VISIBILITY_RESET_HIDE_ALL", "hide-all" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyVisibilityResetType", values);
    }
    return etype;
}

GType
gwy_data_watch_event_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DATA_WATCH_EVENT_ADDED, "GWY_DATA_WATCH_EVENT_ADDED", "added" },
            { GWY_DATA_WATCH_EVENT_CHANGED, "GWY_DATA_WATCH_EVENT_CHANGED", "changed" },
            { GWY_DATA_WATCH_EVENT_REMOVED, "GWY_DATA_WATCH_EVENT_REMOVED", "removed" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDataWatchEventType", values);
    }
    return etype;
}

#include "./menu.h"

GType
gwy_menu_sens_flags_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GFlagsValue values[] = {
            { GWY_MENU_FLAG_DATA, "GWY_MENU_FLAG_DATA", "data" },
            { GWY_MENU_FLAG_UNDO, "GWY_MENU_FLAG_UNDO", "undo" },
            { GWY_MENU_FLAG_REDO, "GWY_MENU_FLAG_REDO", "redo" },
            { GWY_MENU_FLAG_GRAPH, "GWY_MENU_FLAG_GRAPH", "graph" },
            { GWY_MENU_FLAG_LAST_PROC, "GWY_MENU_FLAG_LAST_PROC", "last-proc" },
            { GWY_MENU_FLAG_LAST_GRAPH, "GWY_MENU_FLAG_LAST_GRAPH", "last-graph" },
            { GWY_MENU_FLAG_DATA_MASK, "GWY_MENU_FLAG_DATA_MASK", "data-mask" },
            { GWY_MENU_FLAG_DATA_SHOW, "GWY_MENU_FLAG_DATA_SHOW", "data-show" },
            { GWY_MENU_FLAG_3D, "GWY_MENU_FLAG_3D", "3d" },
            { GWY_MENU_FLAG_FILE, "GWY_MENU_FLAG_FILE", "file" },
            { GWY_MENU_FLAG_VOLUME, "GWY_MENU_FLAG_VOLUME", "volume" },
            { GWY_MENU_FLAG_MASK, "GWY_MENU_FLAG_MASK", "mask" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static("GwyMenuSensFlags", values);
    }
    return etype;
}

#include "./gwymoduleutils-file.h"

GType
gwy_text_header_error_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_TEXT_HEADER_ERROR_SECTION_NAME, "GWY_TEXT_HEADER_ERROR_SECTION_NAME", "section-name" },
            { GWY_TEXT_HEADER_ERROR_SECTION_END, "GWY_TEXT_HEADER_ERROR_SECTION_END", "section-end" },
            { GWY_TEXT_HEADER_ERROR_SECTION_START, "GWY_TEXT_HEADER_ERROR_SECTION_START", "section-start" },
            { GWY_TEXT_HEADER_ERROR_PREFIX, "GWY_TEXT_HEADER_ERROR_PREFIX", "prefix" },
            { GWY_TEXT_HEADER_ERROR_GARBAGE, "GWY_TEXT_HEADER_ERROR_GARBAGE", "garbage" },
            { GWY_TEXT_HEADER_ERROR_KEY, "GWY_TEXT_HEADER_ERROR_KEY", "key" },
            { GWY_TEXT_HEADER_ERROR_VALUE, "GWY_TEXT_HEADER_ERROR_VALUE", "value" },
            { GWY_TEXT_HEADER_ERROR_TERMINATOR, "GWY_TEXT_HEADER_ERROR_TERMINATOR", "terminator" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyTextHeaderError", values);
    }
    return etype;
}

#include "./gwyplaintool.h"

GType
gwy_plain_tool_changed_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GFlagsValue values[] = {
            { GWY_PLAIN_TOOL_CHANGED_DATA, "GWY_PLAIN_TOOL_CHANGED_DATA", "changed-data" },
            { GWY_PLAIN_TOOL_CHANGED_MASK, "GWY_PLAIN_TOOL_CHANGED_MASK", "changed-mask" },
            { GWY_PLAIN_TOOL_CHANGED_SHOW, "GWY_PLAIN_TOOL_CHANGED_SHOW", "changed-show" },
            { GWY_PLAIN_TOOL_CHANGED_SELECTION, "GWY_PLAIN_TOOL_CHANGED_SELECTION", "changed-selection" },
            { GWY_PLAIN_TOOL_FINISHED_SELECTION, "GWY_PLAIN_TOOL_FINISHED_SELECTION", "finished-selection" },
            { 0, NULL, NULL }
        };
        etype = g_flags_register_static("GwyPlainToolChanged", values);
    }
    return etype;
}

#include "./settings.h"

GType
gwy_app_settings_error_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_APP_SETTINGS_ERROR_FILE, "GWY_APP_SETTINGS_ERROR_FILE", "file" },
            { GWY_APP_SETTINGS_ERROR_CORRUPT, "GWY_APP_SETTINGS_ERROR_CORRUPT", "corrupt" },
            { GWY_APP_SETTINGS_ERROR_CFGDIR, "GWY_APP_SETTINGS_ERROR_CFGDIR", "cfgdir" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyAppSettingsError", values);
    }
    return etype;
}


/* Generated data ends here */
